import { App, ThemeFunction, Plugin, Page, PluginObject, PluginConfig } from 'vuepress/core';
import { Author, BasePageFrontMatter } from 'vuepress-shared';
import { ThemeData as ThemeData$1 } from '@vuepress/plugin-theme-data';
import { FontIconAssets, ComponentPluginOptions } from 'vuepress-plugin-components';
import { BlogPluginPageData, BlogPluginOptions, BlogTypeOptions, BlogCategoryOptions } from '@vuepress/plugin-blog';
import { GitPluginPageData, GitPluginOptions, GitData } from '@vuepress/plugin-git';
import { ReadingTime, ReadingTimePluginPageData, ReadingTimePluginOptions } from '@vuepress/plugin-reading-time';
import { SeoPluginPageData, SeoPluginOptions } from '@vuepress/plugin-seo';
import { LocaleData } from 'vuepress/shared';
import { BackToTopPluginOptions } from '@vuepress/plugin-back-to-top';
import { CatalogPluginOptions } from '@vuepress/plugin-catalog';
import { CommentPluginOptions, CommentOptions } from '@vuepress/plugin-comment';
import { CopyCodePluginOptions } from '@vuepress/plugin-copy-code';
import { CopyrightPluginOptions } from '@vuepress/plugin-copyright';
import { DocsearchPluginOptions } from '@vuepress/plugin-docsearch';
import { FeedPluginOptions } from '@vuepress/plugin-feed';
import { LinksCheckPluginOptions } from '@vuepress/plugin-links-check';
import { PhotoSwipePluginOptions } from '@vuepress/plugin-photo-swipe';
import { PwaPluginOptions } from '@vuepress/plugin-pwa';
import { RedirectPluginOptions } from '@vuepress/plugin-redirect';
import { SearchPluginOptions } from '@vuepress/plugin-search';
import { SitemapPluginOptions } from '@vuepress/plugin-sitemap';
import { MarkdownEnhancePluginOptions } from 'vuepress-plugin-md-enhance';
import { SearchProPluginOptions } from 'vuepress-plugin-search-pro';
import { UserConfig } from 'vuepress/cli';

/**
 * @deprecated You should use scss style files in v2 and avoid using it
 */
declare const checkLegacyStyle: (app: App) => void;

declare const enum PageInfo {
    title = "t",
    shortTitle = "s",
    icon = "i",
    index = "I",
    order = "O",
    breadcrumbExclude = "b"
}
declare const enum ArticleInfo {
    type = "y",
    author = "a",
    date = "d",
    localizedDate = "l",
    category = "c",
    tag = "g",
    isEncrypted = "n",
    isOriginal = "o",
    readingTime = "r",
    excerpt = "e",
    sticky = "u",
    cover = "v"
}
declare const enum PageType {
    article = "a",
    home = "h",
    slide = "s",
    page = "p"
}
interface PageInfoData extends Record<string, unknown> {
    /**
     * Article title
     */
    [PageInfo.title]: string;
    /**
     * Article short title
     */
    [PageInfo.shortTitle]: string;
    /**
     * Page icon
     */
    [PageInfo.icon]?: string;
    /**
     * Whether this page should be indexed
     *
     * used in other functions, e.g.: sidebar and catalog
     */
    [PageInfo.index]?: boolean;
    /**
     * The order of this page in same directory
     */
    [PageInfo.order]?: number;
}
interface ArticleInfoData extends PageInfoData {
    /**
     * Type
     */
    [ArticleInfo.type]: PageType;
    /**
     * Article author
     */
    [ArticleInfo.author]?: Author | false;
    /**
     * Writing date info
     */
    [ArticleInfo.date]?: number;
    /**
     * Writing date info in current language
     */
    [ArticleInfo.localizedDate]?: string;
    /**
     * Article category
     */
    [ArticleInfo.category]?: string[];
    /**
     * Article tag
     */
    [ArticleInfo.tag]?: string[];
    /**
     * Reading time info
     */
    [ArticleInfo.readingTime]?: ReadingTime;
    /**
     * Article excerpt
     */
    [ArticleInfo.excerpt]: string;
    /**
     * Whether is encrypted
     */
    [ArticleInfo.isEncrypted]?: true;
    /**
     * Whether is original
     */
    [ArticleInfo.isOriginal]?: true;
    /**
     * Sticky info
     */
    [ArticleInfo.sticky]?: number | boolean;
    /**
     * Cover image
     */
    [ArticleInfo.cover]?: string;
}

interface ThemePageFrontmatter extends BasePageFrontMatter {
    /**
     * Whether is home page
     *
     * 是否是主页
     */
    home?: boolean;
    /**
     * Whether enable navbar
     *
     * 是否启用导航栏
     */
    navbar?: boolean;
    /**
     * Sidebar configuration
     *
     * 侧边栏配置
     */
    sidebar?: false;
    /**
     * Additional Class for Page container
     *
     * 页面容器的额外类名
     */
    containerClass?: string;
}

interface ThemeHopePageFrontmatter extends ThemePageFrontmatter {
    home: true;
    /**
     * @default false
     */
    heroFullScreen?: boolean;
    heroImage?: string;
    heroImageDark?: string;
    heroImageStyle?: Record<string, string> | string;
    heroAlt?: string;
    heroText?: string;
    tagline?: string;
    bgImage?: string | false;
    bgImageDark?: string | false;
    bgImageStyle?: Record<string, string> | string;
}

interface ThemeBlogHomeProjectOptions {
    /**
     * Project name
     *
     * 项目名称
     */
    name: string;
    /**
     * Project description
     *
     * 项目描述
     */
    desc?: string;
    /**
     * Project link
     *
     * 项目链接
     */
    link: string;
    /**
     * Project icon
     *
     * @description image link or icon fontClass are supported, as well as `"link"`、`"project"`、`"book"`、`"article"`、`"friend"`
     *
     * 项目图标
     *
     * @description 支持图片链接或者图标字体类，同时也支持 `"link"`、`"project"`、`"book"`、`"article"`、`"friend"`
     */
    icon?: string;
}
interface ThemeBlogHomePageFrontmatter extends ThemeHopePageFrontmatter {
    layout: "BlogHome";
    /**
     * @default true
     */
    hero?: boolean;
    projects: ThemeBlogHomeProjectOptions[];
}

/**
 * Type of page information
 *
 * 页面信息类型
 */
type PageInfoType = "Author" | "Category" | "Date" | "Original" | "PageView" | "Tag" | "ReadingTime" | "Word";

/**
 * Base link item, displayed as text
 */
interface TextItemOptions {
    /**
     * Text of item
     *
     * 项目文字
     */
    text: string;
    /**
     * Icon of item
     *
     * 项目图标
     */
    icon?: string;
    /**
     * Aria label of item
     *
     * 项目无障碍标签
     */
    ariaLabel?: string;
}
/**
 * Props for `<AutoLink>`
 */
interface AutoLinkOptions extends TextItemOptions {
    /**
     * Link of item
     *
     * 当前页面链接
     */
    link: string;
    /**
     * Rel of `<a>` tag
     *
     * `<a>` 标签的 `rel` 属性
     */
    rel?: string;
    /**
     * Target of `<a>` tag
     *
     * `<a>` 标签的 `target` 属性
     */
    target?: string;
    /**
     * Regexp mode to be active
     *
     * 匹配激活的正则表达式
     */
    activeMatch?: string;
}

interface ThemeNormalPageFrontmatter extends ThemePageFrontmatter {
    /**
     * Whether is homepage
     *
     * 是否是主页
     */
    home?: false;
    /**
     * Whether index current page
     *
     * 是否索引此页面
     *
     * @default true
     */
    index?: boolean;
    /**
     * Page order in sidebar
     *
     * 页面在侧边栏的顺序
     *
     * @default 0
     */
    order?: number;
    /**
     * Dir config
     *
     * @description Only available at README.md
     *
     * 目录配置
     *
     * @description 仅在 README.md 中可用
     */
    dir?: {
        /**
         * Dir title
         *
         * @default title of README.md
         *
         * 目录标题
         *
         * @default README.md 标题
         */
        text?: string;
        /**
         * Dir icon
         *
         * @default icon of README.md
         *
         * 目录图标
         *
         * @default README.md 图标
         */
        icon?: string;
        /**
         * Whether Dir is collapsible
         *
         * 目录是否可折叠
         *
         * @default true
         */
        collapsible?: boolean;
        /**
         * Whether Dir is clickable
         *
         * @description Will set group link to link of README.md
         *
         * 目录是否可点击
         *
         * @description 将会将目录分组的链接设置为 README.md 对应的链接
         *
         * @default false
         */
        link?: boolean;
        /**
         * Whether index current dir
         *
         * 是否索引此目录
         *
         * @default true
         */
        index?: boolean;
        /**
         * Dir order in sidebar
         *
         * 目录在侧边栏中的顺序
         *
         * @default 0
         */
        order?: number;
    };
    /**
     * A short title used in navbar, sidebar and breadcrumb
     *
     * 用于导航栏，侧边栏和路径导航的短标题
     */
    shortTitle?: string;
    /**
     * Page Heading depth
     *
     * 页面标题深度
     */
    headerDepth?: number;
    /**
     * Whether display lastUpdated time
     *
     * 是否显示最后更新事件
     */
    lastUpdated?: boolean;
    /**
     * Whether display contributors
     *
     * 是否显示贡献者
     */
    contributors?: boolean;
    /**
     * Whether show Edit link
     *
     * 是否显示编辑此页链接
     */
    editLink?: boolean;
    /**
     * Previous page link
     *
     * 上一页链接
     */
    prev?: string | AutoLinkOptions;
    /**
     * Next page link
     *
     * 下一页链接
     */
    next?: string | AutoLinkOptions;
    /**
     * Whether show toc list in desktop mode
     *
     * 是否在桌面模式下展示标题列表
     */
    toc?: boolean;
    /**
     * PageInfo items
     *
     * 页面信息项
     *
     * @default ["Author", "Visitor", "Time", "Category", "Tag", "ReadTime"]
     */
    pageInfo?: PageInfoType[] | false;
    /**
     * Whether enable breadcrumb
     *
     * 是否启用路径导航
     */
    breadcrumb?: boolean;
    /**
     * Whether enable breadcrumb icon
     *
     * 是否启用路径导航图标
     */
    breadcrumbIcon?: boolean;
    /**
     * Whether exclude current page in breadcrumb
     *
     * 是否在路径导航中排除
     */
    breadcrumbExclude?: boolean;
    /**
     *
     * Whether enable pageviews
     *
     * @description Only available when using artalk or waline comment service
     *
     * 是否启用访问量
     *
     * @description 仅在使用 Artalk 或 Waline 评论服务时有效
     *
     * @default true
     */
    pageview?: boolean;
    /**
     * Whether this page is an article
     */
    article?: boolean;
    /**
     * Whether the article be sticky in list
     *
     * If a number fill in, greater number will appear in front
     *
     * 是否置顶，如果填入数字，更大值会出现在前面
     */
    sticky?: boolean | number;
    /**
     * Whether the article be stared
     *
     * If a number fill in, greater number will appear in front
     *
     * 是否标为星标，如果填入数字，更大值会出现在前面
     */
    star?: boolean | number;
    /**
     * Page excerpt
     *
     * 页面的摘要
     */
    excerpt?: string;
}

interface ThemeProjectHomeActionOptions {
    /**
     * Action name
     *
     * 操作名称
     */
    text: string;
    /**
     * Action link
     *
     * 操作链接
     */
    link: string;
    /**
     * Type of action
     *
     * 操作类型
     *
     * @default "default"
     */
    type?: "primary" | "default";
    /**
     * Action icon
     *
     * 操作图标
     */
    icon?: string;
}
interface ThemeProjectHomeHighlightItem {
    /**
     * Item name, supports HTML string
     *
     * 项目名称，支持 HTML 字符串
     */
    title: string;
    /**
     * Item description, supports HTML string
     *
     * 项目描述，支持 HTML 字符串
     */
    details?: string;
    /**
     * Item icon
     *
     * @description image link or icon fontClass are supported
     *
     * 项目图标
     *
     * @description 支持图片链接或者图标字体类
     */
    icon?: string;
    /**
     * Item link
     *
     * 项目链接
     */
    link?: string;
}
type ThemeProjectHomeFeatureItem = ThemeProjectHomeHighlightItem;
interface ThemeProjectHomeHighlightOptions {
    /**
     * Highlight section header, supports HTML string
     *
     * 亮点标题，支持 HTML 字符串
     */
    header: string;
    /**
     * Highlight section description, supports HTML string
     *
     * 亮点描述，支持 HTML 字符串
     */
    description?: string;
    /**
     * Text color
     *
     * 文字颜色
     */
    color?: string;
    /**
     * Highlight section image
     *
     * 亮点图像
     */
    image?: string;
    /**
     * Highlight section image used in darkmode
     *
     * 夜间模式使用的亮点图片
     *
     * @default image
     */
    imageDark?: string;
    /**
     * Highlight Background image
     *
     * 亮点背景图
     */
    bgImage?: string;
    /**
     * Highlight Background image used in darkmode
     *
     * 夜间模式使用的亮点背景图
     *
     * @default bgImage
     */
    bgImageDark?: string;
    /**
     * Highlight Background image style
     *
     * 亮点背景图样式
     */
    bgImageStyle?: Record<string, string> | string;
    /**
     * Highlight section list type
     *
     * 亮点列表类型
     *
     * @default un-order
     */
    type?: "order" | "un-order" | "no-order";
    /**
     * Highlights
     *
     * 亮点
     */
    highlights?: ThemeProjectHomeHighlightItem[];
}
interface ThemeProjectHomeFeatureOptions {
    /**
     * Feature header
     *
     * 功能标题
     */
    header?: string;
    /**
     * Feature section description, supports HTML string
     *
     * 功能描述，支持 HTML 字符串
     */
    description?: string;
    /**
     * Text color
     *
     * 文字颜色
     */
    color?: string;
    /**
     * Feature section image
     *
     * 功能图像
     */
    image?: string;
    /**
     * Feature section image used in darkmode
     *
     * 夜间模式使用的功能图片
     *
     * @default image
     */
    imageDark?: string;
    /**
     * Feature Background image
     *
     * 功能背景图
     */
    bgImage?: string;
    /**
     * Feature Background image used in darkmode
     *
     * 夜间模式使用的功能背景图
     *
     * @default bgImage
     */
    bgImageDark?: string;
    /**
     * Feature Background image style
     *
     * 功能背景图样式
     */
    bgImageStyle?: Record<string, string> | string;
    /**
     * Features
     *
     * 功能
     */
    features: ThemeProjectHomeFeatureItem[];
}
interface ThemeProjectHomePageFrontmatter extends ThemeHopePageFrontmatter {
    actions?: ThemeProjectHomeActionOptions[];
    features?: ThemeProjectHomeFeatureItem[];
    highlights?: (ThemeProjectHomeFeatureOptions | ThemeProjectHomeHighlightOptions)[];
}

/**
 * Base nav group, has nav items children
 */
interface NavGroup<T> extends TextItemOptions {
    /**
     * Link prefix of current group
     *
     * 当前分组的页面前缀
     */
    prefix?: string;
    /**
     * Link of current group
     *
     * 当前分组的链接
     */
    link?: string;
    /**
     * Children of current group
     *
     * 当前分组的子项
     */
    children: T[];
}
/**
 * Navbar types
 */
type NavbarItem = AutoLinkOptions;
type NavbarGroup = NavGroup<NavbarGroup | NavbarItem | string>;
type NavbarOptions = (NavbarItem | NavbarGroup | string)[];

type DarkmodeOptions = "switch" | "auto" | "toggle" | "enable" | "disable";
interface OutlookLocaleData {
    /**
     * Theme Color
     */
    themeColor: string;
    /**
     * Theme mode
     */
    darkmode: string;
    /**
     * Theme mode
     */
    fullscreen: string;
}
interface AppearanceLocaleData {
    outlookLocales: {
        /**
         * Theme Color
         *
         * 主题色
         */
        themeColor: string;
        /**
         * Theme mode
         *
         * 夜间模式
         */
        darkmode: string;
        /**
         * Fullscreen text
         *
         * 全屏文字
         */
        fullscreen: string;
    };
}
/**
 * @kind root
 */
interface AppearanceOptions {
    /**
     * Whether enable pure mode
     *
     * 是否开启纯净模式
     *
     * @default false
     */
    pure?: boolean;
    /**
     * Dark mode support options:
     *
     * - `"switch"`: switch between dark, light and auto (default)
     * - `"toggle"`: toggle between lightmode and darkmode
     * - `"auto"`: Automatically decide whether to apply dark mode based on user device’s color-scheme or current time
     * - `"enable"`: only dark mode
     * - `"disable"`: disable dark mode
     *
     * 深色模式支持选项:
     *
     * - `"switch"`: 在深色模式，浅色模式和自动之间切换 (默认)
     * - `"toggle"`: 在深色模式和浅色模式之间切换
     * - `"auto"`: 自动根据用户设备主题或当前时间决定是否应用深色模式
     * - `"enable"`: 强制深色模式
     * - `"disable"`: 禁用深色模式
     *
     * @default "auto-switch"
     */
    darkmode?: DarkmodeOptions;
    /**
     * Whether enable theme color picker
     *
     * 是否启用主题色选择器
     *
     * @default false
     */
    themeColor?: boolean;
    /**
     * Whether display print button in desktop mode
     *
     * 是否在桌面模式下显示打印按钮
     *
     * @default true
     */
    print?: boolean;
    /**
     * Full screen button
     *
     * 全屏按钮
     *
     * @default false
     */
    fullscreen?: boolean;
    /**
     * Link of font icon asset
     *
     * 字体图标资源链接
     *
     * @description `"iconify"`, `"fontawesome"` and `"fontawesome-with-brands"` keywords are supported
     */
    iconAssets?: FontIconAssets;
    /**
     * Font Icon class prefix
     *
     * 字体图标 class 前缀
     *
     * @default ""
     */
    iconPrefix?: string;
}
type AppearanceConfig = AppearanceOptions;

interface BlogLocaleData extends Record<string, string> {
    /** 文章文字 */
    article: string;
    /** 文章列表文字 */
    articleList: string;
    /** 分类文字 */
    category: string;
    /** 标签文字 */
    tag: string;
    /** 时间轴文字 */
    timeline: string;
    /** 时间轴标题文字 */
    timelineTitle: string;
    /** 全部文字 */
    all: string;
    /** 个人介绍 */
    intro: string;
    /** 星标文章 */
    star: string;
    /** 空文字 */
    empty: string;
}
interface PaginationLocaleData {
    /**
     * Previous page button label text
     *
     * 上一页文字
     */
    prev: string;
    /**
     * Next page button label text
     *
     * 下一页文字
     */
    next: string;
    /**
     * Navigation hint label text
     *
     * 跳转提示文字
     */
    navigate: string;
    /**
     * Navigation button label text
     *
     * 跳转按钮文字
     */
    action: string;
    /**
     * Error text when invalid page number
     *
     * @description `$page` will be replaced by total page number automatically
     *
     * 页码错误文字
     *
     * @description 其中 `$page` 会自动替换为当前的总页数
     */
    errorText: string;
}
/**
 * 博客选项
 *
 * Blog configuration
 *
 * @kind locale
 */
interface BlogLocaleOptions {
    /**
     * Name of the Blogger
     *
     * 博主名称
     *
     * @default themeConfig.author
     */
    name?: string;
    /**
     * Blogger avatar, must be an absolute path
     *
     * 博主头像，应为绝对路径
     *
     * @default themeConfig.navbar.logo
     */
    avatar?: string;
    /**
     * Motto, slogan or a short description
     *
     * 口号、座右铭或介绍语
     */
    description?: string;
    /**
     * Blogger introduction page link
     *
     * 博主的个人介绍页地址
     */
    intro?: string;
    /**
     * 媒体链接配置
     *
     * Media links configuration
     *
     * @example
     *
     * ```js
     * {
     *   QQ: "http://wpa.qq.com/msgrd?v=3&uin=1178522294&site=qq&menu=yes",
     *   Qzone: "https://1178522294.qzone.qq.com/",
     *   Gmail: "mailto:mister-hope@outlook.com",
     *   Zhihu: "https://www.zhihu.com/people/mister-hope",
     *   Steam: "https://steamcommunity.com/id/Mr-Hope/",
     *   Weibo: "https://weibo.com/misterhope",
     * }
     * ```
     */
    medias?: Record<string, [string, string] | string>;
    /**
     * Whether to display blogger info in sidebar
     *
     * 是否在侧边栏展示博主信息
     *
     * @default "mobile"
     */
    sidebarDisplay?: "mobile" | "none" | "always";
    /**
     * Custom text for timeline
     *
     * 时间轴自定义文字
     *
     * @default "Yesterday once more"
     */
    timeline?: string;
    /**
     * Article number per page
     *
     * 每页的文章数量
     *
     * @default 10
     */
    articlePerPage?: number;
    /**
     * Article info displayed in article list
     *
     * 文章列表中展示的文章信息
     *
     * @default ["Author", "Original", "Date", "PageView", "ReadingTime", "Category", "Tag"]
     */
    articleInfo?: PageInfoType[];
}
interface BlogLocaleConfig extends Omit<BlogLocaleOptions, "media"> {
    medias?: Record<string, string>;
}

interface EncryptLocaleData {
    /**
     * Aria label for encrypt icon
     *
     * 加密图标的无障碍标签
     */
    iconLabel: string;
    /**
     * Password placeholder
     *
     * 密码输入框的默认占位符
     */
    placeholder: string;
    /**
     * Whether remember password
     *
     * 是否记忆密码
     */
    remember: string;
    /**
     * Password error hint
     *
     * 密码错误提示
     */
    errorHint: string;
}
/**
 * Encrypt Options
 *
 * 加密选项
 *
 * @kind root
 */
interface EncryptOptions {
    /**
     * Whether encrypt globally
     *
     * 是否全局加密
     *
     * @default false
     */
    global?: boolean;
    /**
     * Admin passwords, which has the highest authority
     *
     * 最高权限密码
     */
    admin?: string | string[];
    /**
     * Encrypt Configuration
     *
     * @example
     *
     * ```json
     * {
     *   // This will encrypt the entire guide directory and both passwords will be available
     *   "/guide/": ["1234", "5678"],
     *   // this will only encrypt /config/page.html
     *   "/config/page.html": "1234"
     * }
     * ```
     *
     * 加密配置
     *
     * @example
     *
     * ```json
     * {
     *   // 这会加密整个 guide 目录，并且两个密码都是可用的
     *   "/guide/": ["1234", "5678"],
     *   // 这只会加密 /config/page.html
     *   "/config/page.html": "1234"
     * }
     * ```
     */
    config?: Record<string, string | string[]>;
}
/**
 * Encrypt Config
 *
 * 加密配置
 *
 * @kind root
 */
interface EncryptConfig {
    /**
     * Whether encrypt globally
     *
     * 是否全局加密
     *
     * @default false
     */
    global?: boolean;
    /**
     * Admin passwords, which has the highest authority
     *
     * 最高权限密码
     */
    admin?: string[];
    /**
     * Encrypt Configuration
     *
     * 加密配置
     */
    config?: Record<string, string[]>;
}

interface FeatureLocaleData {
    /**
     * Blog related i18n config
     *
     * 博客相关多语言配置
     */
    blogLocales: BlogLocaleData;
    /**
     * Pagination related i18n config
     *
     * 分页相关多语言配置
     */
    paginationLocales: PaginationLocaleData;
    /**
     * Encrypt related i18n config
     *
     * 加密相关多语言配置
     */
    encryptLocales: EncryptLocaleData;
}
interface FeatureLocaleOptions {
    /**
     * Blog feature options
     *
     * 博客功能配置
     */
    blog?: BlogLocaleOptions;
}
interface FeatureLocaleConfig {
    blog?: BlogLocaleConfig;
}
/**
 * @kind root
 */
interface FeatureOptions {
    /**
     * Encrypt config
     *
     * 加密配置
     */
    encrypt?: EncryptOptions;
    /**
     * Whether enable hotReload for features that requires app to restart
     *
     * @description These features includes blog support and structure sidebar feature
     *
     * 是否为需要重启整个 app 的功能启用热更新
     *
     * @description 这些功能包括博客支持和结构侧边栏功能
     *
     * @default app.env.isDebug
     */
    hotReload?: boolean;
}
interface FeatureConfig extends FeatureLocaleConfig {
    /**
     * Encrypt config
     *
     * 加密配置
     */
    encrypt: EncryptConfig;
}

/**
 * 页脚选项
 *
 * Footer options
 */
interface FooterLocaleOptions {
    /**
     * The default content for the footer, supports HTMLString.
     *
     * 页脚的默认内容，支持 HTMLString
     */
    footer?: string;
    /**
     * The default copyright info, set it to `false` to disable it by default.
     *
     * 默认的版权信息，设置为 `false` 来默认禁用它
     */
    copyright?: string | false;
    /**
     * Whether to display footer by default
     *
     * 是否默认显示页脚
     *
     * @default false
     */
    displayFooter?: boolean;
}

interface DocsRepoLocaleOptions {
    /**
     * Pattern of edit link, we provide built-in support for GitHub, Gitlab, Gitee, Bitbucket
     *
     * 编辑链接的匹配，我们已经为 GitHub、Gitlab、Gitee 和 Bitbucket 提供了内置支持
     *
     * @example ":repo/edit/:branch/:path"
     */
    editLinkPattern?: string;
    /**
     * The repo of your docs
     *
     * 文档仓库
     *
     * @default themeConfig.repo
     */
    docsRepo?: string;
    /**
     * The branch of your docs
     *
     * 文档所在分支
     *
     * @default "main"
     */
    docsBranch?: string;
    /**
     * Docs dir location in repo
     *
     * 文档在仓库中的目录
     *
     * @default ""
     */
    docsDir?: string;
}

interface MetaLocateData {
    /**
     * Author label text
     *
     * 作者文字
     */
    author: string;
    /**
     * Writing date label text
     *
     * 写作日期文字
     */
    date: string;
    /**
     * Label text marked as original
     *
     * 标记原创的文字
     */
    origin: string;
    /**
     * Page views label text
     *
     * 访问量文字
     */
    views: string;
    /**
     * Tag label text
     *
     * 标签文字
     */
    tag: string;
    /**
     * Category label text
     *
     * 分类文字
     */
    category: string;
    /**
     * Expect reading time label text
     *
     * 期望阅读时间文字
     */
    readingTime: string;
    /**
     * Words label Text
     *
     * 文章字数
     */
    words: string;
    /**
     * Table of contents
     *
     * 此页内容
     */
    toc: string;
    /**
     * Previous link
     *
     * 上一页
     */
    prev: string;
    /**
     * Next link
     *
     * 下一页
     */
    next: string;
    /**
     * Last updated Text
     *
     * 最后更新时间
     */
    lastUpdated: string;
    /**
     * Contributors text
     *
     * 贡献者
     */
    contributors: string;
    /**
     * Edit link text
     *
     * 编辑此页
     */
    editLink: string;
    /**
     * Print button
     *
     * 打印按钮
     */
    print: string;
}
interface MetaLocaleOptions {
    /**
     * Whether to show "Last Updated" or not
     *
     * 是否显示页面最后更新时间
     *
     * @default true
     */
    lastUpdated?: boolean;
    /**
     * Whether to show "Contributors" or not
     *
     * 是否显示页面贡献者
     *
     * @default true
     */
    contributors?: boolean;
    /**
     * Whether to show "Edit this page" or not
     *
     * 是否展示编辑此页链接
     *
     * @default true
     */
    editLink?: boolean;
}

interface NavbarLocaleData {
    /**
     * Aria label of of the language selection dropdown
     *
     * 语言下拉列表的无障碍标签
     */
    selectLangAriaLabel: string;
    /**
     * Language name of current locale
     *
     * 当前语言的名称
     */
    langName: string;
}
/**
 * Navbar component
 *
 * 导航栏组件
 */
type NavbarComponent = "Brand" | "Links" | "Language" | "Search" | "Outlook" | "Repo";
/**
 * Navbar layout options
 *
 * 导航栏布局选项
 */
interface NavbarLayoutOptions {
    start?: string[];
    center?: string[];
    end?: string[];
}
interface NavbarLocaleOptions {
    /**
     * Navbar config
     *
     * @description Set to `false` to disable navbar in current locale
     *
     * @see https://theme-hope.vuejs.press/guide/layout/navbar.html
     *
     * 导航栏配置
     *
     * @description 设置 `false` 以在当前语言中禁用导航栏
     *
     * @see https://theme-hope.vuejs.press/v2/zh/guide/layout/navbar.html
     */
    navbar?: NavbarOptions | false;
    /**
     * Navbar logo
     *
     * @description should be absolute path relative to `.vuepress/public` folder
     *
     * 导航栏图标
     *
     * @description 应为基于 `.vuepress/public` 文件夹的绝对路径
     */
    logo?: string;
    /**
     * Navbar logo under darkmode
     *
     * @description should be absolute path relative to `.vuepress/public` folder
     *
     * 夜间模式下导航栏图标
     *
     * @description 应为基于 `.vuepress/public` 文件夹的绝对路径
     */
    logoDark?: string;
    /**
     * Navbar title
     *
     * 导航栏标题
     *
     * @default $siteLocale.title
     */
    navbarTitle?: string;
    /**
     * Repository link
     *
     * 仓库链接
     */
    repo?: string;
    /**
     * Whether display repo link in navbar.
     *
     * 是否在导航栏显示仓库链接。
     *
     * @default true
     */
    repoDisplay?: boolean;
    /**
     * Repository aria label of navbar
     *
     * 导航栏仓库按钮的无障碍标签
     */
    repoLabel?: string;
    /**
     * Whether to hide navbar when scrolling down
     *
     * 是否在向下滚动时自动隐藏导航栏
     *
     * @default "mobile"
     */
    navbarAutoHide?: "always" | "mobile" | "none";
    /**
     * Navbar layout config
     *
     * 导航栏布局设置
     *
     * @default { start: ["Brand"], center: ["Links"], end: ["Language", "Repo", "Outlook", "Search"] }
     */
    navbarLayout?: NavbarLayoutOptions;
    /**
     * Whether hide site title on mobile
     *
     * 是否在移动视图下隐藏站点名称
     *
     * @default true
     */
    hideSiteNameOnMobile?: boolean;
}

interface RouteLocaleData {
    /**
     * Skip to main content
     */
    skipToContent: string;
    /**
     * 404 page title
     *
     * 404 页面的标题
     */
    notFoundTitle: string;
    /**
     * 404 page msgs
     *
     * 404 页面的提示信息
     */
    notFoundMsg: string[];
    /**
     * Back to homepage
     *
     * 返回主页
     */
    home: string;
    /**
     * Back to last page
     *
     * 返回上一页
     */
    back: string;
    /**
     * Screen reader only message in `<ExternalLinkIcon>`
     *
     * 在 `<ExternalLinkIcon>` 中的屏幕阅读器消息
     */
    openInNewWindow: string;
}

interface ThemePageData extends BlogPluginPageData, Partial<GitPluginPageData>, Partial<ReadingTimePluginPageData>, Partial<SeoPluginPageData> {
    filePathRelative: string | null;
}

type SidebarPageItem = AutoLinkOptions;
interface SidebarStructureItem extends TextItemOptions {
    /**
     * Link prefix of current group
     *
     * 当前分组的页面前缀
     */
    prefix?: string;
    /**
     * Link of current group
     *
     * 当前分组的链接
     */
    link?: string;
    /**
     * Whether current group is collapsible
     *
     * 当前分组的链接是否可折叠
     *
     * @default false
     */
    collapsible?: boolean;
    children: "structure";
}
interface SidebarGroupItem extends TextItemOptions {
    /**
     * Link prefix of current group
     *
     * 当前分组的页面前缀
     */
    prefix?: string;
    /**
     * Link of current group
     *
     * 当前分组的链接
     */
    link?: string;
    /**
     * Whether current group is collapsible
     *
     * 当前分组的链接是否可折叠
     *
     * @default false
     */
    collapsible?: boolean;
    /**
     * Children of current group
     *
     * 当前分组的子项
     */
    children: (SidebarPageItem | SidebarGroupItem | SidebarStructureItem | string)[];
}
type SidebarItem = SidebarPageItem | SidebarGroupItem | SidebarStructureItem | string;
type SidebarArrayOptions = SidebarItem[];
type SidebarObjectOptions = Record<string, SidebarArrayOptions | "structure" | false>;
type SidebarOptions = SidebarArrayOptions | SidebarObjectOptions | "structure" | false;

interface SidebarFileInfo {
    type: "file";
    filename: string;
    title: string;
    order: number | null;
    path?: string | null;
    frontmatter: ThemeNormalPageFrontmatter;
    pageData: ThemePageData;
}
interface SidebarDirInfo {
    type: "dir";
    dirname: string;
    children: SidebarInfo[];
    title: string;
    order: number | null;
    groupInfo: {
        icon?: string;
        collapsible?: boolean;
        link?: string;
    };
    frontmatter: ThemeNormalPageFrontmatter | null;
    pageData: ThemePageData | null;
}
type SidebarInfo = SidebarFileInfo | SidebarDirInfo;
type SidebarSorterKeyword = "readme" | "order" | "date" | "date-desc" | "filename" | "title";
type SidebarSorterFunction = (infoA: SidebarInfo, infoB: SidebarInfo) => number;
type SidebarSorter = SidebarSorterFunction | SidebarSorterFunction[] | SidebarSorterKeyword | SidebarSorterKeyword[];
interface SidebarLocaleOptions {
    /**
     * Sidebar config
     *
     * @description Set to `false` to disable sidebar in current locale
     * @see https://theme-hope.vuejs.press/guide/layout/sidebar.html
     *
     * 侧边栏配置
     *
     * @description 设置为 `false` 以在当前语言中禁用侧边栏
     * @see https://theme-hope.vuejs.press/zh/guide/layout/sidebar.html
     */
    sidebar?: SidebarOptions;
    /**
     * Heading depth for sidebar and toc
     *
     * - Set to `0` to disable all levels
     * - Set to `1` to include `<h2>`
     * - Set to `2` to include `<h2>` and `<h3>`
     * - ...
     *
     * The max value depends on which headers you have extracted
     * via `markdown.headers.level`.
     *
     * The default value of `markdown.headers.level` is `[2, 3]`,
     * so the default max value of `headerDepth` is `2`
     *
     * 侧边栏和页面目录的标题深度
     *
     * - 设置 `0` 来禁用所有级别的标题
     * - 设置 `1` 来包含 `<h2>`
     * - 设置 `2` 来包含 `<h2>` 和 `<h3>`
     * - ...
     *
     * `markdown.headers.level` 的默认值是 `[2, 3]`,
     * 所以 `headerDepth` 的默认最大值是 `2`
     *
     * @default 2
     */
    headerDepth?: number;
}

interface LayoutLocaleData {
    /**
     * Navbar related i18n config
     */
    navbarLocales: NavbarLocaleData;
    /**
     * Meta related i18n config
     */
    metaLocales: MetaLocateData;
    /**
     * Router related i18n config
     */
    routeLocales: RouteLocaleData;
}
interface LayoutLocaleOptions extends NavbarLocaleOptions, SidebarLocaleOptions, DocsRepoLocaleOptions, MetaLocaleOptions, FooterLocaleOptions {
    /**
     * Home path of current locale
     *
     * @description Used as the link of back-to-home and navbar logo
     *
     * 当前语言的主页路径
     *
     * @description 用于导航栏图标和返回主页按钮的链接
     */
    home?: string;
    /**
     * Whether enable breadcrumb globally
     *
     * 是否全局启用路径导航
     *
     * @default true
     */
    breadcrumb?: boolean;
    /**
     * Whether display icon in breadcrumb
     *
     * 是否在路径导航显示图标
     *
     * @default true
     */
    breadcrumbIcon?: boolean;
    /**
     * Whether display icon besides page title
     *
     * 是否在页面标题旁显示图标
     *
     * @default true
     */
    titleIcon?: boolean;
    /**
     * Article Info display configuration
     *
     * @see https://theme-hope.vuejs.press/guide/feature/page-info.html
     *
     * 文章信息配置
     *
     * @see https://theme-hope.vuejs.press/zh/guide/feature/page-info.html
     *
     * @default ["Author", "Original", "Date", "PageView", "ReadingTime", "Category", "Tag"]
     */
    pageInfo?: PageInfoType[] | false;
    /**
     * Whether show toc list in desktop mode
     *
     * 是否在桌面模式下展示标题列表
     *
     * @default true
     */
    toc?: boolean;
    /**
     * Whether rtl layout should be used
     *
     * 是否使用 rtl 布局
     *
     * @default false
     */
    rtl?: boolean;
    /**
     * Whether display nextLink
     *
     * 是否显示 下一篇 链接
     *
     * @default true
     */
    nextLink?: boolean;
    /**
     * Whether display prevLink
     *
     * 是否显示 上一篇 链接
     *
     * @default true
     */
    prevLink?: boolean;
}
type LayoutLocaleConfig = LayoutLocaleOptions;
/**
 * @kind root
 */
interface LayoutOptions {
    /**
     * Sorter of structure sidebar
     *
     * 结构化侧边栏排序器
     *
     * @default ["readme", "index", "title", "filename"]
     */
    sidebarSorter?: SidebarSorter;
}

interface InfoOptions {
    /**
     * Site favicon
     *
     * 站点图标
     */
    favicon?: string;
    /**
     * Global default author
     *
     * 全局默认作者
     */
    author?: Author;
    /**
     * Global default license
     *
     * 全局默认协议
     */
    license?: string;
    /**
     * Domain which to be deployed to
     *
     * 网站部署域名
     */
    hostname?: string;
    /**
     * Extra i18n sites
     *
     * @description key is the name of language, and value is the path of site, `:route` will be replaced by current route
     *
     * 额外的多语言站点
     *
     * @description 键是语言的名称，值是站点的路径，`:route` 会被替换为当前路由
     */
    extraLocales?: Record<string, string>;
}

type LocaleDataToOption<T> = {
    [P in keyof T]?: Partial<T[P]>;
};

interface ThemeLocaleData extends AppearanceLocaleData, FeatureLocaleData, LayoutLocaleData {
    /**
     * Current lang code
     */
    lang: string;
}
interface ThemeLocaleOptions extends LocaleData, LocaleDataToOption<AppearanceLocaleData>, LocaleDataToOption<FeatureLocaleData>, FeatureLocaleOptions, LocaleDataToOption<LayoutLocaleData>, LayoutLocaleOptions {
    /**
     * Global default author
     *
     * 全局默认作者
     */
    author?: Author;
}
interface ThemeLocaleConfig extends LocaleData, ThemeLocaleData, FeatureLocaleConfig, LayoutLocaleConfig {
    /**
     * Global default author
     *
     * 全局默认作者
     */
    author?: Author;
}

interface BlogOptions extends Partial<Pick<BlogPluginOptions, "excerptFilter" | "excerptLength" | "excerptSeparator" | "filter" | "slugify" | "hotReload">> {
    /**
     * Path of article list
     *
     * 文章列表的路径
     *
     * @default "/article/"
     */
    article?: string;
    /**
     * Path of category map
     *
     * 分类地图页的地址
     *
     * @default "/category/"
     */
    category?: string;
    /**
     * Path to navigate when clicking category label
     *
     * `:name` will be automatically replaced by current category name
     *
     * 点击分类标签时跳转的路径。
     *
     * 其中 `:name` 会被自动替换为当前分类名称
     *
     * @default "/category/:name/"
     */
    categoryItem?: string;
    /**
     * Path of tag map
     *
     * 标签地图页的地址
     *
     * @default "/tag/"
     */
    tag?: string;
    /**
     * Path to navigate when clicking tag label
     *
     * `:name` will be automatically replaced by current tag name
     *
     * 点击标签跳转的路径。
     *
     * 其中 `:name` 会被自动替换为当前分类名称
     *
     * @default "/tag/:name/"
     */
    tagItem?: string;
    /**
     * Path of star article list
     *
     * 星标文章列表的路径
     *
     * @default "/star/""
     */
    star?: string;
    /**
     * Path of timeline
     *
     * 时间线路径
     *
     * @default "/timeline/"
     */
    timeline?: string;
    /**
     * Excerpt generation
     *
     * 摘要生成
     *
     * @default true
     */
    excerpt?: boolean;
    /**
     * Additional Article Type
     *
     * @description This is an advanced option, please refer to the [blog plugin documentation](https://ecosystem.vuejs.press/plugins/blog/) for details
     *
     * 额外的文章类型
     *
     * @description 这是一个高级选项，请参考 [blog 插件文档](https://ecosystem.vuejs.press/zh/plugins/blog/) 了解详情
     *
     * @default []
     */
    type?: BlogTypeOptions[];
}

type PrismjsLightTheme = "ateliersulphurpool-light" | "coldark-cold" | "coy" | "duotone-light" | "ghcolors" | "gruvbox-light" | "material-light" | "one-light" | "vs";
type PrismjsDarkTheme = "atom-dark" | "cb" | "coldark-dark" | "dark" | "dracula" | "duotone-dark" | "duotone-earth" | "duotone-forest" | "duotone-sea" | "duotone-space" | "gruvbox-dark" | "holi" | "hopscotch" | "lucario" | "material-dark" | "material-oceanic" | "night-owl" | "nord" | "one-dark" | "pojoaque" | "shades-of-purple" | "solarized-dark-atom" | "tomorrow" | "vsc-dark-plus" | "xonokai" | "z-touch";
type PrismjsTheme = PrismjsDarkTheme | PrismjsLightTheme;
interface PrismjsOptions {
    /**
     * Light theme
     *
     * @default 'one-light'
     */
    light?: PrismjsTheme;
    /**
     * Dark theme
     * @default 'one-dark'
     */
    dark?: PrismjsTheme;
}

interface PluginsOptions {
    /**
     * Enable @vuepress/active-header-links or not
     *
     * @see https://ecosystem.vuejs.press/plugins/active-header-links.html
     *
     * 是否启用 @vuepress/active-header-links 插件
     *
     * @see https://ecosystem.vuejs.press/zh/plugins/active-header-links.html
     *
     * @default true
     */
    activeHeaderLinks?: boolean;
    /**
     * Options for @vuepress/back-to-top
     *
     * @see https://ecosystem.vuejs.press/plugins/back-to-top.html
     *
     * 返回顶部插件配置
     *
     * @see https://ecosystem.vuejs.press/zh/plugins/back-to-top.html
     */
    backToTop?: BackToTopPluginOptions | boolean;
    /**
     * Blog plugin options
     *
     * 博客插件选项
     *
     * @default false
     */
    blog?: BlogOptions | boolean;
    /**
     * Options for @vuepress/catalog
     *
     * @see https://ecosystem.vuejs.press/plugins/catalog.html
     *
     * 自动目录插件选项
     *
     * @see https://ecosystem.vuejs.press/plugins/catalog.html
     *
     * @default true
     */
    catalog?: CatalogPluginOptions | boolean;
    /**
     * Components enabled
     *
     * @description FontIcon is used internally, so it will be registered anyway.
     *
     * @see https://plugin-components.vuejs.press/config.html
     *
     * 需要启用的插件
     *
     * @description FontIcon 被内部使用，所以它无论如何都会被注册。
     *
     * @see https://plugin-components.vuejs.press/zh/config.html
     */
    components?: ComponentPluginOptions;
    /**
     * Comment plugin options
     *
     * @see https://ecosystem.vuejs.press/plugins/comment/
     *
     * 评论插件配置
     *
     * @see https://ecosystem.vuejs.press/zh/plugins/comment/
     */
    comment?: CommentPluginOptions | false;
    /**
     * Options for @vuepress/copy-code
     *
     * @see https://ecosystem.vuejs.press/plugins/copy-code.html
     *
     * 代码复制插件配置
     *
     * @see https://ecosystem.vuejs.press/zh/plugins/copy-code.html
     */
    copyCode?: CopyCodePluginOptions | boolean;
    /**
     * Options for @vuepress/copyright
     *
     * @see https://ecosystem.vuejs.press/plugins/copyright.html
     *
     * 版权信息插件配置
     *
     * @see https://ecosystem.vuejs.press/zh/plugins/copyright.html
     *
     * @default false
     */
    copyright?: CopyrightPluginOptions | boolean;
    /**
     * Options for @vuepress/docsearch
     *
     * @see https://ecosystem.vuejs.press/plugins/docsearch.html
     *
     * @vuepress/docsearch 选项
     *
     * @see https://ecosystem.vuejs.press/zh/plugins/docsearch.html
     */
    docsearch?: DocsearchPluginOptions;
    /**
     * Enable @vuepress/external-link-icon or not
     *
     * @see https://ecosystem.vuejs.press/plugins/external-link-icon.html
     *
     * 是否启用 @vuepress/external-link-icon 插件
     *
     * @see https://ecosystem.vuejs.press/zh/plugins/external-link-icon.html
     *
     * @default true
     */
    externalLinkIcon?: boolean;
    /**
     * Feed plugin options
     *
     * @see https://ecosystem.vuejs.press/plugins/feed/config.html
     *
     * Feed 插件配置
     *
     * @see https://ecosystem.vuejs.press/zh/plugins/feed/config.html
     */
    feed?: Omit<FeedPluginOptions, "hostname"> | boolean;
    /**
     * Options for @vuepress/git
     *
     * @description By default this plugin is only enabled in production mode for performance reasons.
     *
     * @see https://ecosystem.vuejs.press/plugins/git.html
     *
     * Git 插件配置
     *
     * @description 默认情况下，出于性能原因，此插件仅在生产模式下启用。
     *
     * @see https://ecosystem.vuejs.press/zh/plugins/git.html
     */
    git?: GitPluginOptions | boolean;
    /**
     * Options for @vuepress/links-check
     *
     * @see https://ecosystem.vuejs.press/plugins/links-check.html
     *
     * @vuepress/links-check 插件配置
     *
     * @see https://ecosystem.vuejs.press/zh/plugins/links-check.html
     */
    linksCheck?: LinksCheckPluginOptions | boolean;
    /**
     * md-enhance plugin options
     *
     * @see https://plugin-md-enhance.vuejs.press/config/
     *
     * md-enhance 插件配置
     *
     * @see https://plugin-md-enhance.vuejs.press/zh/config/
     */
    mdEnhance?: (Omit<MarkdownEnhancePluginOptions, "hint"> & {
        /**
         * Whether to enable hint container including
         *
         * - important
         * - info
         * - note
         * - tip
         * - warning
         * - caution
         * - details
         *
         * 是否启用提示容器
         *
         * - important
         * - info
         * - note
         * - tip
         * - warning
         * - caution
         * - details
         *
         * @default true
         */
        hint?: boolean;
    }) | false;
    /**
     * Enable @vuepress/nprogress or not
     *
     * 是否启用 @vuepress/nprogress 插件
     *
     * @default true
     */
    nprogress?: boolean;
    /**
     * Photo Swipe plugin options
     *
     * @description This plugin is enabled by default
     *
     * @see https://ecosystem.vuejs.press/plugins/photo-swipe.html
     *
     * 图片预览插件配置
     *
     * @see https://ecosystem.vuejs.press/zh/plugins/photo-swipe.html
     *
     * @default true
     */
    photoSwipe?: PhotoSwipePluginOptions | boolean;
    /**
     * Enable @vuepress/prismjs or not
     *
     * @see https://ecosystem.vuejs.press/plugins/prismjs.html
     *
     * 是否启用 @vuepress/prismjs 插件
     *
     * @see https://ecosystem.vuejs.press/zh/plugins/prismjs.html
     *
     * @default true
     */
    prismjs?: PrismjsOptions | boolean;
    /**
     * PWA plugin options
     *
     * @see https://ecosystem.vuejs.press/plugins/pwa/config.html
     *
     * PWA 插件配置
     *
     * @see https://ecosystem.vuejs.press/zh/plugins/pwa/config.html
     *
     * @default false
     */
    pwa?: PwaPluginOptions | boolean;
    /**
     * ReadingTime options
     *
     * @see https://ecosystem.vuejs.press/plugins/reading-time.html
     *
     * 阅读时间插件配置
     *
     * @see https://ecosystem.vuejs.press/zh/plugins/reading-time.html
     *
     * @default true
     */
    readingTime?: ReadingTimePluginOptions | boolean;
    /**
     * Redirect options
     *
     * @see https://ecosystem.vuejs.press/plugins/redirect.html
     *
     * 重定向插件配置
     *
     * @see https://ecosystem.vuejs.press/zh/plugins/redirect.html
     */
    redirect?: RedirectPluginOptions | boolean;
    /**
     * @vuepress/search plugin options
     *
     * @see https://ecosystem.vuejs.press/plugins/search.html
     *
     * @vuepress/search 插件配置
     *
     * @see https://ecosystem.vuejs.press/zh/plugins/search.html
     */
    search?: SearchPluginOptions | boolean;
    /**
     * search-pro plugin options
     *
     * @see https://plugin-search-pro.vuejs.press/config/
     *
     * search-pro 插件配置
     *
     * @see https://plugin-search-pro.vuejs.press/zh/config/
     */
    searchPro?: SearchProPluginOptions | boolean;
    /**
     * Options for @vuepress/seo
     *
     * @see https://ecosystem.vuejs.press/plugins/seo/config.html
     *
     * SEO 插件配置
     *
     * @see https://ecosystem.vuejs.press/zh/plugins/seo/config.html
     *
     * @default true
     */
    seo?: Omit<SeoPluginOptions, "hostname" | "author"> | boolean;
    /**
     * Options for @vuepress/sitemap
     *
     * @see https://ecosystem.vuejs.press/plugins/sitemap/config.html
     *
     * Sitemap 插件配置
     *
     * @see https://ecosystem.vuejs.press/zh/plugins/sitemap/config.html
     *
     * @default true
     */
    sitemap?: Omit<SitemapPluginOptions, "hostname"> | boolean;
}

interface ThemeOptions extends AppearanceOptions, FeatureOptions, InfoOptions, LayoutOptions, ThemeData$1<ThemeLocaleOptions> {
    plugins?: PluginsOptions;
}
interface ThemeData extends AppearanceConfig, FeatureConfig, InfoOptions {
    locales: Record<string, ThemeLocaleConfig>;
}

/**
 * @deprecated You should use V2 standard frontmatter and avoid using it
 */
declare const convertFrontmatter: (frontmatter: Record<string, unknown>, filePathRelative?: string | null) => ThemePageFrontmatter & Record<string, unknown>;

/**
 * @deprecated You should use V2 standard navbar config and avoid using it
 */
declare const convertNavbarOptions: (config: unknown) => NavbarOptions | false;

/**
 * @deprecated You should use V2 standard sidebar config and avoid using it
 */
declare const convertSidebarOptions: (config: unknown) => SidebarOptions | false;

/**
 * @deprecated You should use V2 standard options and avoid using it
 */
declare const convertThemeOptions: (themeOptions: Record<string, unknown>) => ThemeOptions;

/**
 * @deprecated use `import { navbar } from "vuepress-theme-hope";` instead
 */
declare const navbarConfig: (config: NavbarOptions) => NavbarOptions;
/**
 * @deprecated use `import { arraySidebar } from "vuepress-theme-hope";` instead
 */
declare const sidebarConfig: (config: SidebarOptions) => SidebarOptions;
/**
 * @deprecated use `import { hopeThemeLegacy } from "vuepress-theme-hope";` instead
 */
declare const themeConfig: (themeConfig: ThemeOptions) => ThemeOptions;
/**
 * @deprecated import and use `hopeTheme` instead
 */
declare const config: (userConfig: Record<string, unknown>) => UserConfig;

/**
 * @deprecated use `import { navbar } from "vuepress-theme-hope";` instead
 */
declare const defineNavbarConfig: (config: NavbarOptions) => NavbarOptions;
/**
 * @deprecated use `import { sidebar } from "vuepress-theme-hope";` instead
 */
declare const defineSidebarConfig: (config: SidebarOptions) => SidebarOptions;
/**
 * @deprecated use `import { arraySidebar } from "vuepress-theme-hope";` instead
 */
declare const defineSidebarArrayConfig: (config: SidebarArrayOptions) => SidebarArrayOptions;
/**
 * @deprecated use `import { objectSidebar } from "vuepress-theme-hope";` instead
 */
declare const defineSidebarObjectConfig: (config: SidebarObjectOptions) => SidebarObjectOptions;
/**
 * @deprecated use `import { hopeThemeLegacy } from "vuepress-theme-hope";` instead
 */
declare const defineThemeConfig: (themeConfig: ThemeOptions) => ThemeOptions;
/**
 * @deprecated import and use `hopeTheme` instead
 */
declare const defineHopeConfig: (config: UserConfig & Record<string, unknown>) => UserConfig;

interface HopeThemeBehaviorOptions {
    /**
     * Whether perform extra checks
     *
     * 是否执行额外检查
     *
     * @default false
     */
    check?: boolean;
    /**
     * Whether compact with historical versions
     *
     * 是否兼容历史版本
     *
     * @default false
     */
    compact?: boolean;
    /**
     * Whether enable customization
     *
     * 是否启用自定义
     *
     * @default false
     */
    custom?: boolean;
    /**
     * Whether enable debug mode
     *
     * 是否启用调试模式
     *
     * @default false
     */
    debug?: boolean;
}

type Helper<T> = (options: T) => T;
type ThemeNavbarHelper = Helper<NavbarOptions>;
type ThemeSidebarHelper = Helper<SidebarOptions>;
type ThemeSidebarArrayHelper = Helper<SidebarArrayOptions>;
type ThemeSidebarObjectHelper = Helper<SidebarObjectOptions>;
type ThemeBackToTopPluginHelper = Helper<BackToTopPluginOptions | boolean>;
type ThemeBlogPluginHelper = Helper<BlogOptions | boolean>;
type ThemeCommentPluginHelper = Helper<CommentOptions | false>;
type ThemeComponentPluginHelper = Helper<ComponentPluginOptions | false>;
type ThemeCopyCodePluginHelper = Helper<CopyCodePluginOptions | false>;
type ThemeCopyrightPluginHelper = Helper<CopyrightPluginOptions | false>;
type ThemeFeedPluginHelper = Helper<Omit<FeedPluginOptions, "hostname"> | false>;
type ThemeGitPluginHelper = Helper<GitPluginOptions | false>;
type ThemeLinksCheckPluginHelper = Helper<LinksCheckPluginOptions | false>;
type ThemeMdEnhancePluginHelper = Helper<MarkdownEnhancePluginOptions | false>;
type ThemePhotoSwipePluginHelper = Helper<PhotoSwipePluginOptions | false>;
type ThemePrismJsPluginHelper = Helper<PrismjsOptions | false>;
type ThemePwaPluginHelper = Helper<PwaPluginOptions | false>;
type ThemeReadingTimePluginHelper = Helper<ReadingTimePluginOptions | false>;
type ThemeRedirectPluginHelper = Helper<RedirectPluginOptions | false>;
type ThemeSEOPluginHelper = Helper<Omit<SeoPluginOptions, "hostname" | "author"> | false>;
type ThemeSitemapPluginHelper = Helper<Omit<SitemapPluginOptions, "hostname"> | false>;

declare const navbar: ThemeNavbarHelper;
declare const sidebar: ThemeSidebarHelper;
declare const arraySidebar: ThemeSidebarArrayHelper;
declare const objectSidebar: ThemeSidebarObjectHelper;
declare const backToTop: ThemeBackToTopPluginHelper;
declare const blog: ThemeBlogPluginHelper;
declare const comment: ThemeCommentPluginHelper;
declare const components: ThemeComponentPluginHelper;
declare const copyCode: ThemeCopyCodePluginHelper;
declare const copyright: ThemeCopyrightPluginHelper;
declare const feed: ThemeFeedPluginHelper;
declare const git: ThemeGitPluginHelper;
declare const linkCheck: ThemeLinksCheckPluginHelper;
declare const mdEnhance: ThemeMdEnhancePluginHelper;
declare const photoSwipe: ThemePhotoSwipePluginHelper;
declare const prismjs: ThemePrismJsPluginHelper;
declare const pwa: ThemePwaPluginHelper;
declare const readingTime: ThemeReadingTimePluginHelper;
declare const redirect: ThemeRedirectPluginHelper;
declare const seo: ThemeSEOPluginHelper;
declare const sitemap: ThemeSitemapPluginHelper;

declare const hopeTheme: (options: ThemeOptions, behavior?: HopeThemeBehaviorOptions | boolean) => ThemeFunction;

declare const themeLocalesData: Record<string, ThemeLocaleData>;

/** @private */
declare const getEncryptConfig: (encrypt?: EncryptOptions) => EncryptConfig;

/** @private */
declare const getSocialMediaIcons: (themeData: ThemeData) => Record<string, string>;

interface ThemeStatus {
    enableBlog: boolean;
    enableCatalog: boolean;
    enableEncrypt: boolean;
    enableSlide: boolean;
    enableReadingTime: boolean;
    blogType: {
        key: string;
        path: string;
    }[];
    hasMultipleLanguages: boolean;
}
/** @private */
declare const getThemeStatus: (app: App, themeOptions: ThemeOptions) => ThemeStatus;

/**
 * @private
 *
 * Get client-side `themeData`
 */
declare const getThemeData: (app: App, themeOptions: ThemeOptions, { enableBlog, enableEncrypt }: ThemeStatus) => ThemeData;

/**
 * @private
 */
declare const extendsBundlerOptions: (bundlerOptions: unknown, app: App) => void;

/**
 * @private
 */
declare const getAlias: (isDebug: boolean) => Record<string, string>;

/**
 * @private
 *
 * Resolve options for @vuepress/plugin-active-header-links
 */
declare const getActiveHeaderLinksPlugin: (activeHeaderLinks?: boolean) => Plugin | null;

/**
 * @private
 *
 * Resolve options for @vuepress/plugin-catalog
 */
declare const getCatalogPlugin: (catalog?: CatalogPluginOptions | boolean) => Plugin | null;

/** @private */
declare const getBlogPlugin: (app: App, themeData: ThemeData, options?: BlogOptions | boolean, hotReload?: boolean) => Plugin | null;

/** @private */
declare const getBlogCategoryCategory: (options: BlogOptions, themeData: ThemeData) => BlogCategoryOptions<{
    git: GitData;
}, ThemeNormalPageFrontmatter, {
    routeMeta: ArticleInfoData;
}>;
/** @private */
declare const getBlogTagCategory: (options: BlogOptions, themeData: ThemeData) => BlogCategoryOptions<{
    git: GitData;
}, ThemeNormalPageFrontmatter, {
    routeMeta: ArticleInfoData;
}>;

/** @private */
declare const blogFilter: ({ frontmatter, filePathRelative, }: Page<ThemePageData>) => boolean;

/** @private */
declare const injectBlogBasicInfo: (page: Page<ThemePageData>, info: Record<string, unknown>) => void;

/** @private */
declare const getBlogArticleType: (options: BlogOptions, themeData: ThemeData) => BlogTypeOptions<{
    git: GitData;
}, ThemeNormalPageFrontmatter, {
    routeMeta: ArticleInfoData;
}>;
/** @private */
declare const getBlogStarType: (options: BlogOptions, themeData: ThemeData) => BlogTypeOptions<{
    git: GitData;
}, ThemeNormalPageFrontmatter, {
    routeMeta: ArticleInfoData;
}>;
/** @private */
declare const getBlogTimelineType: (options: BlogOptions, themeData: ThemeData) => BlogTypeOptions<{
    git: GitData;
}, ThemeNormalPageFrontmatter, {
    routeMeta: ArticleInfoData;
}>;

/** @private */
declare const defaultPageSorter: (pageA: Page<{
    git: GitData;
}, ThemeNormalPageFrontmatter, {
    routeMeta: ArticleInfoData;
}>, pageB: Page<{
    git: GitData;
}, ThemeNormalPageFrontmatter, {
    routeMeta: ArticleInfoData;
}>) => number;

/**
 * @private
 *
 * Resolve options for @vuepress/plugin-comment
 */
declare const getCommentPlugin: (options?: Partial<CommentPluginOptions> | false) => PluginObject | null;

/**
 * @private
 *
 * Resolve options for vuepress-plugin-components
 */
declare const getComponentsPlugin: (options: Pick<ThemeOptions, "hostname" | "hotReload" | "iconAssets" | "iconPrefix">, { components, componentOptions, rootComponents, }?: ComponentPluginOptions, legacy?: boolean) => Plugin;

/**
 * @private
 *
 * Resolve options for @vuepress/plugin-copy-code
 */
declare const getCopyCodePlugin: (options?: CopyCodePluginOptions | boolean) => Plugin | null;

/**
 * @private
 *
 * Resolve options for vuepress-plugin-copyright
 */
declare const getCopyrightPlugin: (themeData: ThemeData, options?: Partial<CopyrightPluginOptions> | boolean, hostname?: string) => Plugin | null;

/**
 * @private
 *
 * Resolve options for @vuepress/plugin-feed
 */
declare const getFeedPlugin: (themeData: ThemeData, options?: Omit<FeedPluginOptions, "hostname"> | boolean | undefined, hostname?: string, favicon?: string, legacy?: boolean) => Plugin | null;

/**
 * @private
 *
 * Get theme plugins
 */
declare const getPlugins: (app: App, pluginsOptions: PluginsOptions, themeData: ThemeData, options: Pick<ThemeOptions, "hostname" | "hotReload" | "iconAssets" | "iconPrefix" | "favicon">, legacy?: boolean) => PluginConfig;

/**
 * @private
 *
 * Resolve options for vuepress-plugin-md-enhance
 */
declare const getMdEnhancePlugin: (options?: Partial<MarkdownEnhancePluginOptions> | false, legacy?: boolean) => Plugin | null;

/**
 * @private
 *
 * Inject basic page info
 */
declare const injectPageInfo: (page: Page<ThemePageData>) => void;
declare const extendsPagePlugin: (themeData: ThemeData, behavior: HopeThemeBehaviorOptions) => PluginObject;
declare const useExtendsPagePlugin: (app: App, themeData: ThemeData, behavior: HopeThemeBehaviorOptions) => void;

/**
 * @private
 *
 * Resolve options for @vuepress/plugin-photo-swipe
 */
declare const getPhotoSwipePlugin: (options?: PhotoSwipePluginOptions | boolean) => Plugin | null;

/**
 * @private
 *
 * Composition Api to use `@vuepress/plugin-prismjs`
 */
declare const usePrismjsPlugin: (app: App) => void;
/**
 * @private
 *
 * Composition Api to remove `@vuepress/plugin-prismjs`
 */
declare const removePrismjsPlugin: (app: App) => void;

/**
 * @private
 *
 * Resolve options for @vuepress/plugin-pwa
 */
declare const getPwaPlugin: (options?: PwaPluginOptions | boolean, favicon?: string) => Plugin | null;

/**
 * @private
 *
 * Resolve options for @vuepress/plugin-rt
 */
declare const getRtlPlugin: (themeData: ThemeData) => Plugin | null;

/**
 * @private
 *
 * Resolve options for @vuepress/plugin-docsearch, @vuepress/plugin-search and vuepress-plugin-search-pro
 */
declare const getSearchPlugin: (app: App, themeData: ThemeData, plugins: PluginsOptions) => Plugin | null;

/**
 * @private
 *
 * Resolve options for @vuepress/plugin-seo
 */
declare const getSEOPlugin: (themeData: ThemeData, { seo }: PluginsOptions, hostname?: string) => Plugin | null;

/**
 * @private
 *
 * Resolve options for @vuepress/plugin-sitemap
 */
declare const getSitemapPlugin: (options?: Omit<SitemapPluginOptions, "hostname"> | boolean, hostname?: string) => Plugin | null;

/**
 * @private
 *
 * Use plugins to ensure they apply first
 */
declare const usePlugins: (app: App, themeData: ThemeData, plugins: PluginsOptions, hotReload: boolean, behavior: HopeThemeBehaviorOptions) => void;

/**
 * @private
 */
declare const prepareBundleConfigFile: (app: App, { enableCatalog, enableBlog, enableEncrypt, enableSlide }: ThemeStatus) => Promise<string>;

/**
 * @private
 */
declare const prepareHighLighterScss: (app: App, { prismjs }: PluginsOptions) => Promise<void>;

/**
 * @private
 */
declare const prepareSeparatedConfigFile: (app: App, { enableCatalog, enableBlog, enableEncrypt, enableSlide }: ThemeStatus) => Promise<string>;

/**
 * @private
 */
declare const prepareSocialMediaIcons: (app: App, icons: Record<string, string>) => Promise<void>;

declare const sidebarReadmeSorter: (infoA: SidebarInfo, infoB: SidebarInfo) => number;
declare const sidebarOrderSorter: (infoA: SidebarInfo, infoB: SidebarInfo) => number;
declare const sidebarDateSorter: (infoA: SidebarInfo, infoB: SidebarInfo) => number;
declare const sidebarDateDescSorter: (infoA: SidebarInfo, infoB: SidebarInfo) => number;
declare const sidebarFilenameSorter: (infoA: SidebarInfo, infoB: SidebarInfo) => number;
declare const sidebarTitleSorter: (infoA: SidebarInfo, infoB: SidebarInfo) => number;
/** @private */
declare const getSidebarSorter: (sorter?: SidebarSorter) => SidebarSorterFunction[];

interface FileInfo {
    type: "file";
    filename: string;
    path: string;
}
interface DirInfo {
    type: "dir";
    dirname: string;
    path: string;
    children: StructureInfo[];
}
type StructureInfo = DirInfo | FileInfo;
/**
 * @private
 */
declare const getStructureInfo: (pages: Page[], scope: string) => StructureInfo[];

/**
 * @private
 */
declare const getSidebarData: (app: App, themeData: ThemeData, sorter?: SidebarSorter) => SidebarOptions;
/**
 * @private
 */
declare const prepareSidebarData: (app: App, themeData: ThemeData, sorter?: SidebarSorter) => Promise<void>;

export { type AppearanceConfig, type AppearanceLocaleData, type AppearanceOptions, ArticleInfo, type ArticleInfoData, type AutoLinkOptions, type BlogLocaleConfig, type BlogLocaleData, type BlogLocaleOptions, type BlogOptions, type DarkmodeOptions, type DirInfo, type DocsRepoLocaleOptions, type EncryptConfig, type EncryptLocaleData, type EncryptOptions, type FeatureConfig, type FeatureLocaleConfig, type FeatureLocaleData, type FeatureLocaleOptions, type FeatureOptions, type FileInfo, type FooterLocaleOptions, type HopeThemeBehaviorOptions, type InfoOptions, type LayoutLocaleConfig, type LayoutLocaleData, type LayoutLocaleOptions, type LayoutOptions, type MetaLocaleOptions, type MetaLocateData, type NavGroup, type NavbarComponent, type NavbarGroup, type NavbarItem, type NavbarLayoutOptions, type NavbarLocaleData, type NavbarLocaleOptions, type NavbarOptions, type OutlookLocaleData, PageInfo, type PageInfoData, type PageInfoType, PageType, type PaginationLocaleData, type PluginsOptions, type PrismjsDarkTheme, type PrismjsLightTheme, type PrismjsOptions, type PrismjsTheme, type RouteLocaleData, type SidebarArrayOptions, type SidebarDirInfo, type SidebarFileInfo, type SidebarGroupItem, type SidebarInfo, type SidebarItem, type SidebarLocaleOptions, type SidebarObjectOptions, type SidebarOptions, type SidebarPageItem, type SidebarSorter, type SidebarSorterFunction, type SidebarSorterKeyword, type SidebarStructureItem, type StructureInfo, type TextItemOptions, type ThemeBackToTopPluginHelper, type ThemeBlogHomePageFrontmatter, type ThemeBlogHomeProjectOptions, type ThemeBlogPluginHelper, type ThemeCommentPluginHelper, type ThemeComponentPluginHelper, type ThemeCopyCodePluginHelper, type ThemeCopyrightPluginHelper, type ThemeData, type ThemeFeedPluginHelper, type ThemeGitPluginHelper, type ThemeHopePageFrontmatter, type ThemeLinksCheckPluginHelper, type ThemeLocaleConfig, type ThemeLocaleData, type ThemeLocaleOptions, type ThemeMdEnhancePluginHelper, type ThemeNavbarHelper, type ThemeNormalPageFrontmatter, type ThemeOptions, type ThemePageData, type ThemePageFrontmatter, type ThemePhotoSwipePluginHelper, type ThemePrismJsPluginHelper, type ThemeProjectHomeActionOptions, type ThemeProjectHomeFeatureItem, type ThemeProjectHomeFeatureOptions, type ThemeProjectHomeHighlightItem, type ThemeProjectHomeHighlightOptions, type ThemeProjectHomePageFrontmatter, type ThemePwaPluginHelper, type ThemeReadingTimePluginHelper, type ThemeRedirectPluginHelper, type ThemeSEOPluginHelper, type ThemeSidebarArrayHelper, type ThemeSidebarHelper, type ThemeSidebarObjectHelper, type ThemeSitemapPluginHelper, type ThemeStatus, arraySidebar, backToTop, blog, blogFilter, checkLegacyStyle, comment, components, config, convertFrontmatter, convertNavbarOptions, convertSidebarOptions, convertThemeOptions, copyCode, copyright, defaultPageSorter, defineHopeConfig, defineNavbarConfig, defineSidebarArrayConfig, defineSidebarConfig, defineSidebarObjectConfig, defineThemeConfig, extendsBundlerOptions, extendsPagePlugin, feed, getActiveHeaderLinksPlugin, getAlias, getBlogArticleType, getBlogCategoryCategory, getBlogPlugin, getBlogStarType, getBlogTagCategory, getBlogTimelineType, getCatalogPlugin, getCommentPlugin, getComponentsPlugin, getCopyCodePlugin, getCopyrightPlugin, getEncryptConfig, getFeedPlugin, getMdEnhancePlugin, getPhotoSwipePlugin, getPlugins, getPwaPlugin, getRtlPlugin, getSEOPlugin, getSearchPlugin, getSidebarData, getSidebarSorter, getSitemapPlugin, getSocialMediaIcons, getStructureInfo, getThemeData, getThemeStatus, git, hopeTheme, injectBlogBasicInfo, injectPageInfo, linkCheck, mdEnhance, navbar, navbarConfig, objectSidebar, photoSwipe, prepareBundleConfigFile, prepareHighLighterScss, prepareSeparatedConfigFile, prepareSidebarData, prepareSocialMediaIcons, prismjs, pwa, readingTime, redirect, removePrismjsPlugin, seo, sidebar, sidebarConfig, sidebarDateDescSorter, sidebarDateSorter, sidebarFilenameSorter, sidebarOrderSorter, sidebarReadmeSorter, sidebarTitleSorter, sitemap, themeConfig, themeLocalesData, useExtendsPagePlugin, usePlugins, usePrismjsPlugin };
